@@ -3,6 +3,7 @@ import cupy as cp
 import numpy as np
 import math
 from .CustomKernel import CustomKernel, Stream
+from torchpq.util import get_absolute_path
 
 class ComputeProductCUDA(CustomKernel):
   def __init__(
@@ -20,7 +21,7 @@ class ComputeProductCUDA(CustomKernel):
     self._use_torch_in_cupy_malloc()
     self.stream = Stream(torch.cuda.current_stream().cuda_stream)
 
-    with open("ComputeProductKernel.cu", "r") as f:
+    with open(get_absolute_path("ComputeProductKernel.cu"), "r") as f:
       self.kernel = f.read()
     
     cb1 = [f"      float Bval{i} = Bsh[(i * _NCS_ + {i}) * _K_ + int(Avals.d{i}) ];" for i in range(n_cs)]
