@@ -3,6 +3,7 @@ import cupy as cp
 import numpy as np
 import math
 from torchpq.kernels.CustomKernel import CustomKernel, Stream
+from torchpq.util import get_absolute_path
 
 class ComputeCentroidsCUDA(CustomKernel):
   def __init__(
@@ -19,7 +20,7 @@ class ComputeCentroidsCUDA(CustomKernel):
     self._use_torch_in_cupy_malloc()
     self.stream = Stream(torch.cuda.current_stream().cuda_stream)
 
-    with open("./ComputeCentroidsKernel.cu", "r") as f:
+    with open(get_absolute_path("ComputeCentroidsKernel.cu"), "r") as f:
       self.kernel = f.read()
 
     kernel = (self.kernel
